#!/bin/bash

# Verifica se è stato fornito un file come argomento
if [ $# -ne 1 ]; then
  echo "Utilizzo: $0 <file_input>"
  exit 1
fi

# Assegna il nome del file di input a una variabile
input_file="$1"

# Verifica se il file di input esiste
if [ ! -f "$input_file" ]; then
  echo "Errore: il file '$input_file' non esiste."
  exit 1
fi

# Legge il file riga per riga
while IFS= read -r line; do
  # Divide la riga in indirizzo IP e hostname
  ip=$(echo "$line" | awk '{print $1}')
  hostname=$(echo "$line" | awk '{print $2}')

  # Verifica se l'indirizzo IP e l'hostname sono stati estratti correttamente
  if [ -n "$ip" ] && [ -n "$hostname" ]; then
    # Verifica se la voce esiste già nel file /etc/hosts
    if ! grep -q "$ip\s\+$hostname" /etc/hosts; then
      # Aggiunge la voce al file /etc/hosts
      echo "$ip $hostname" | sudo tee -a /etc/hosts > /dev/null
      echo "Aggiunta voce: $ip $hostname"
    else
      echo "Voce già esistente: $ip $hostname"
    fi
  else
    echo "Riga non valida: $line"
  fi
done < "$input_file"

echo "Operazione completata."
